% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statGraph.R
\name{GIC}
\alias{GIC}
\title{Graph Information Criterion (GIC)}
\usage{
GIC(A, model, p = NULL, bandwidth = "Silverman")
}
\arguments{
\item{A}{a symmetric matrix of nonnegative real values. For unweighted graphs 
it contains only 0s and 1s and corresponds to the adjacency matrix. For 
weighted graphs, it may contain any nonnegative real value and corresponds to
the weighted adjancency matrix.}

\item{model}{either a list, a string or a function describing a graph model: 

A list that represents the spectral density of a model. It contains the 
components "x" and "y", which are numeric vectors of the same size. The "x" 
component contains the points at which the density was computed and the "y" 
component contains the observed density.

A string that indicates one of the following models: "ER" (Erdos-Renyi random 
graph), "GRG" (geometric random graph), "KR" (k regular 
random graph), "WS" (Watts-Strogatz model), and "BA" (Barabási-Albert model).
When the argument model is a string, the user must also provide the model 
parameter by using the argument p.  

A function that returns a graph according to a graph model. It must have two 
arguments: n (graph size) and p (a model parameter). The model parameter 
will be provided by the argument p of the GIC function.}

\item{p}{the model parameter. The user must provide a valid parameter if the
argument "model" is a string or a function. For the "ER", "GRG", "KR", "WS", 
and "BA" models, the parameter p corresponds to the probability to connect a 
pair of vertices, the radius used to contruct the geometric graph in a unit 
square, the degree k of a regular graph, the probability to reconnect a 
vertex, and the scale exponent, respectively.}

\item{bandwidth}{string indicating which criterion should be used
to choose the bandwidth for the spectral density estimation. The available 
criteria are "Silverman" (default) and "Sturges".}
}
\value{
A real number corresponding to the Kullback-Leibler divergence 
between the observed graph and a given model.
}
\description{
Returns the Kullback-Leibler divergence between an observed graph and a given 
graph model.
}
\examples{
library(igraph)
A <- as.matrix(get.adjacency(erdos.renyi.game(100, p=0.5)))
# Using a string to indicate the graph model
result1 <- GIC(A, "ER", 0.5)
result1

# Using a function to describe the graph model
# Erdos-Renyi graph
model <- function(n, p) {
   return(as.matrix(get.adjacency(erdos.renyi.game(n, p))))
}
result2 <- GIC(A, model, 0.5)
result2
}
\references{
Daniel Yasumasa Takahashi, João Ricardo Sato, Carlos Eduardo Ferreira, and 
André Fujita. Discriminating Different Classes of Biological Networks by 
Analyzing the adjacencyMatrices Spectra Distribution. PLoS ONE 7, no. 12 
(December 2012): e49949. doi:10.1371/journal.pone.0049949.
}

