% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statGraph.R
\name{ganova}
\alias{ganova}
\title{GANOVA Graph Analysis of Variability}
\usage{
ganova(graph, labels, maxBoot = 1000)
}
\arguments{
\item{labels}{an array of integers indicating the labels of each graph}

\item{maxBoot}{the number of bootstrap samples to be generated}

\item{x}{a list of adjacency matrices of graphs}
}
\value{
pvalue the p-value of the test
}
\description{
This function statistically tests whether two or more sets of graphs are generated by the same
random graph model. It is a generalization of the graph.test function.
}
\examples{
library(igraph)
tamGraph1 <- 50
tamGraph2 <- 50
tamGraph3 <- 50
maxGraphs1 <- maxGraphs2 <- maxGraphs3 <- 50
p1 <- rnorm(maxGraphs1, 0, 1)        ## ER graphs with p~N(0,1)
p2 <- rnorm(maxGraphs2, 0.7, 1)      ## ER graphs with p~N(0.7,1)
p3 <- rnorm(maxGraphs3, 0, 1)        ## ER graphs with p~N(0,1)
tmp <- c(p1, p2, p3)
p1 <- (p1 - min(tmp)) / (max(tmp) - min(tmp))
p2 <- (p2 - min(tmp)) / (max(tmp) - min(tmp))
p3 <- (p3 - min(tmp)) / (max(tmp) - min(tmp))
g.adj <- list()
cont <- 1
for (sim in 1:maxGraphs1) {
    g <- erdos.renyi.game(tamGraph1, p1[sim])
    g.adj[[cont]] <- get.adjacency(g)
    cont <- cont+1
}
for (sim in 1:maxGraphs2) {
    g <- erdos.renyi.game(tamGraph2, p2[sim])
    g.adj[[cont]] <- get.adjacency(g)
    cont <- cont+1
}
for (sim in 1:maxGraphs3) {
    g <- erdos.renyi.game(tamGraph3, p3[sim])
    g.adj[[cont]] <- get.adjacency(g)
    cont <- cont+1
}
label <- array(0, (maxGraphs1+maxGraphs2+maxGraphs3))
label[1:maxGraphs1] <- 1
label[(maxGraphs1+1):(maxGraphs1+maxGraphs2)] <- 2
label[(maxGraphs1+maxGraphs2+1) : (maxGraphs1+maxGraphs2+maxGraphs2)] <- 3
ganova(g.adj, label, maxBoot=100)

}

