% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statGraph.R
\name{graph.cluster}
\alias{graph.cluster}
\title{Hierarchical cluster analysis on a list of graphs.}
\usage{
graph.cluster(x, k, method = "complete")
}
\arguments{
\item{x}{a list containing the adjacency matrices of the graphs}

\item{k}{the number of clusters}

\item{method}{the agglomeration method to be used. This should be 
(an unambiguous abbreviation of) one of ‘"ward.D"’, ‘"ward.D2"’,
‘"single"’, ‘"complete"’, ‘"average"’ (= UPGMA), ‘"mcquitty"’
(= WPGMA), ‘"median"’ (= WPGMC) or ‘"centroid"’ (= UPGMC).}
}
\value{
hclust an object of class *hclust* which described the tree produced
               by the clustering process

cluster the clustering labels for each graph
}
\description{
Hierarchical cluster analysis on a list of graphs.
}
\examples{
require(igraph)
g <- list()
for (i in 1:10) {
    g[[i]] <- as.matrix(igraph::get.adjacency(
                        igraph::erdos.renyi.game(100, 0.5, type="gnp",
                        irected = FALSE)))
}
for (i in 11:20) {
    g[[i]] <- as.matrix(igraph::get.adjacency(
                        igraph::watts.strogatz.game(1, 100, 8, 0.2)))
}
for (i in 21:30) {
    g[[i]] <- as.matrix(igraph::get.adjacency(
                        igraph::barabasi.game(100, power = 1,
                                              directed = FALSE)))
}
graph.cluster(g, 3)

}

