% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statGraph.R
\name{graph.entropy}
\alias{graph.entropy}
\title{Graph spectral entropy}
\usage{
graph.entropy(A, bandwidth = "Silverman")
}
\arguments{
\item{A}{a symmetric matrix of nonnegative real values. For unweighted graphs 
it contains only 0s and 1s and corresponds to the adjacency matrix. For 
weighted graphs, it may contain any nonnegative real value and corresponds to
the weighted adjancency matrix.}

\item{bandwidth}{string indicating which criterion should be used
to choose the bandwidth for the spectral density estimation. The available 
criteria are "Silverman" (default) and "Sturges".}
}
\value{
a real number corresponding to the graph spectral entropy.
}
\description{
Given an adjacency matrix A, it returns the spectral entropy of the 
corresponding graph.
}
\examples{
library(igraph)
G <- erdos.renyi.game(100, p=0.5)
A <- as.matrix(get.adjacency(G))
entropy <- graph.entropy(A)
entropy

}
\references{
Daniel Yasumasa Takahashi, João Ricardo Sato, Carlos Eduardo Ferreira, and 
André Fujita. Discriminating Different Classes of Biological Networks by 
Analyzing the Graph Spectra Distribution. PLoS ONE 7, no. 12 
(December 2012): e49949. doi:10.1371/journal.pone.0049949.
}

