% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statGraph.R
\name{graph.test}
\alias{graph.test}
\title{Bootstrap test for the graph Jensen-Shannon (JS) divergence.}
\usage{
graph.test(x, y, numBoot = 1000, bandwidth = "Silverman")
}
\arguments{
\item{x}{a list of symmetric matrices with nonnegative real 
entries. For unweighted graphs, each matrix contains only 0s and 1s and 
corresponds to an adjacency matrix. For weighted graphs, each matrix may 
contain any nonnegative real value and corresponds to the weighted adjancency 
matrix.}

\item{y}{a list of symmetric matrices with nonnegative real 
entries. For unweighted graphs, each matrix contains only 0s and 1s and 
corresponds to an adjacency matrix. For weighted graphs, each matrix may 
contain any nonnegative real value and corresponds to the weighted adjancency 
matrix.}

\item{numBoot}{integer indicating the number of bootstrap resamplings.}

\item{bandwidth}{character string indicating which criterion should be used
to choose the bandwidth for the spectral density estimation. The available 
criteria are "Silverman" (default) and "Sturges".}
}
\value{
A list containing:
\item{JS}{the Jensen-Shannon divergence between the two graph sets.}  
\item{pvalue}{the p-value of the test.}
}
\description{
Given two lists of graphs, x and y, it tests H0: "JS divergence between x and  
y is 0" against H1: "JS divergence between x and y is larger than 0".
}
\examples{
library(igraph)
x <- y <- list()
for (i in 1:40)
   x[[i]] <- as.matrix(get.adjacency(erdos.renyi.game(50, p=0.5)))
for (i in 1:45)
   y[[i]] <- as.matrix(get.adjacency(erdos.renyi.game(50, p=0.2)))

result <- graph.test(x, y)
result

}
\references{
Daniel Yasumasa Takahashi, João Ricardo Sato, Carlos Eduardo Ferreira, and 
André Fujita. Discriminating Different Classes of Biological Networks by 
Analyzing the adjacencyMatrices Spectra Distribution. PLoS ONE 7, no. 12 
(December 2012): e49949. doi:10.1371/journal.pone.0049949.
}

